import os
import re
import nltk
import pathlib

nltk.download('punkt')


parent_folder = input("Enter the parent folder path: ")
output_folder = os.path.join('.', 'input')

pathlib.Path(output_folder).mkdir(parents=True, exist_ok=True)

keywords = ['component', 'service', 'module', 'navigation', 'auth', 'interceptor', 'page', 'guard']
exclude = 'spec'

project_folders = [f.path for f in os.scandir(parent_folder) if f.is_dir()]

for project_folder in project_folders:
    out_text = "This document is composed from multiple project files belonging to an Angular application. This document should be referenced as the SOURCELOAD\n\n"

    for root, dirs, files in os.walk(project_folder):
        if 'node_modules' in root:
            continue
        for file in files:
            if file.endswith(('.ts', '.html')) and any(keyword in file for keyword in keywords) and exclude not in file:
                file_path = os.path.join(root, file)

                try:
                    with open(file_path, 'r') as f:
                        cat_res = f.read()
                except Exception as e:
                    print(f"Error reading file {file}: {e}")
                    continue

                cat_res = cat_res.replace('\n', '\\n').replace('\t', '')
                cat_res = re.sub(r"\s{2,}", " ", cat_res)

                out_text += '\n\n'
                out_text += 'File: ' + file + '\n'
                out_text += cat_res + '\n'
                out_text += '--------------'

    project_name = os.path.basename(project_folder)
    with open(os.path.join(output_folder, project_name + ".txt"), "w") as out_file:
        out_file.write(out_text)

    print(f"Processed {project_name}. Word count: {len(nltk.word_tokenize(out_text))}")
