import pandas as pd
import os

# Directory containing the CSV files
folder_path = os.path.join('.', 'tmp')

# Name of the output Excel file
output_xlsx = os.path.join('.', 'evaluations', 'sensitive_raw.xlsx')

# Create a Pandas Excel writer using XlsxWriter as the engine
writer = pd.ExcelWriter(output_xlsx, engine='xlsxwriter')

# Iterate through all files in the specified directory
for filename in os.listdir(folder_path):
    if filename.endswith('.csv'):
        # Construct the full path of the file
        file_path = os.path.join(folder_path, filename)
        
        # Read the CSV file using the specified delimiter and skipping bad lines
        df = pd.read_csv(file_path, delimiter=';', error_bad_lines=False)

        # Identify rows where all cells are NaN except the first column
        mask = df.iloc[:, 1:].isna().all(axis=1)

        # Find valid data above and below
        mask &= (mask.shift(-1, fill_value=True) | mask.shift(1, fill_value=True))

        # Drop rows where the mask is True
        df = df.loc[~mask]

        # Sheet name is the first 20 characters of the original CSV file's name
        sheet_name = filename[:20]

        # Write the DataFrame to the specified sheet in the Excel file
        df.to_excel(writer, sheet_name=sheet_name, index=False)
# Save the Excel file
writer.save()
print('Conversion complete!')
