import os
import pandas as pd
from openpyxl import load_workbook
from openpyxl.styles import Alignment
import tempfile

# Define the directory containing the CSV files
csv_dir = os.path.join('tmp')

# Define the directory for the output Excel file
output_dir = os.path.join('evaluations')
os.makedirs(output_dir, exist_ok=True)  # Create the directory if it doesn't exist

# Define the output Excel file
output_file = os.path.join(output_dir, 'sensitive-services.xlsx')

# Create a Pandas Excel writer using XlsxWriter as the engine
writer = pd.ExcelWriter(output_file, engine='openpyxl')

# Iterate over all files in the directory
for filename in os.listdir(csv_dir):
    if filename.endswith('.csv'):
        # Open the CSV file
        with open(os.path.join(csv_dir, filename), 'r') as f:
            lines = f.readlines()
        
        # Remove empty lines
        lines = [line for line in lines if line.strip() != ""]
        
        # Write the lines to a temporary file
        with tempfile.NamedTemporaryFile(mode='w+', delete=False, suffix='.csv') as tempf:
            tempf.writelines(lines)
        
        # Load the temporary file into a DataFrame
        df = pd.read_csv(tempf.name, delimiter=';', error_bad_lines=False)
        
        # If the 'Classname' column is empty, fill it with the values from the 'GoalName' column
        df['Classname'] = df['Classname'].fillna(df['GoalName'])
        
        # Filter the rows where either the Origin or the Goal field has a value of 'Service'
        df_origin = df[df['Origin'] == 'Service'].copy()
        df_goal = df[df['Goal'] == 'Service'].copy()
        
        # Create the new DataFrame
        df_origin['ServiceName'] = df_origin['ServiceName']
        df_goal['ServiceName'] = df_goal['GoalName']
        
        df_new = pd.concat([df_origin, df_goal])
        
        # Select only the required columns and rename them
        df_new = df_new[['ServiceName', 'Level', 'Element', 'Function', 'Classname']]
        
        # Sort by ServiceName and write the DataFrame to the Excel file
        df_new.sort_values(by=['ServiceName']).to_excel(writer, sheet_name=os.path.splitext(filename)[0], index=False)

        # Remove the temporary file
        os.remove(tempf.name)

# Save the Excel file
writer.save()